%
% Average Measurement, Test routine
%
% author: samuel.dubouloz@cea.fr
%         CEA-LETI - May, 2005
%

%% Initialization
% Signal parameters
Tres   = 50e-12;   % Temporal resolution              [s]
BW     = 2e9;      % Signal Bandwidth                 [Hz]
Fc     = 4.1e9;    % Signal center frequency          [Hz]
PRF    = 100e6;    % Pulse Repetition Frequency       [Hz]
PRP    = 1/PRF;    % Mean Pulse Repetition Periode    [s]

% Spectrum Analyzer Parameters
RBW    = 1e6;      % Resolution BandWidth             [Hz]
Tvideo = .2e-3;    % Video Integration Time (average) [s]
VBW    =  3e6;     % Video Bandwidth (peak meas)      [Hz]

% If slow measurement algorithm is used :
% Frequency range of measurement
Fstart = Fc-BW;
Fstop  = Fc+BW;
Fstep  = 100e6;

%% Signal Generation
[t,pulse]                     = GausPulse(Tres, Fc, BW, PRP);
Signal                        = zeros(1,round(1.1*Tvideo/Tres));
Signal(1:round(PRP/Tres):end) = 1;
Signal                        = conv(Signal,pulse);

%% Average Power Measurement
% Average measurement with Spectrum Analyzer Algorithm (very slow)
% [Freq, AvPowerdBm] = AverageMeasurement_Slow(Signal, Tres, Fstart, Fstop, Fstep, Tvideo)

% Average measurement with the PSD calculation
[Freq, AvPowerdBm] = AverageMeasurement(Signal, Tres, Tvideo, RBW);

%% Plots
FCC = FCC_ETSI_mask(Freq);

figure
plot(Freq(1:end)/1e9, AvPowerdBm(1:end), Freq(1:end)/1e9, FCC(1:end),'r'), grid
axis([0 6 -100 -10]), title(['Average Power Measurement - PRF = ' num2str(PRF/1e6) ' MHz'])
xlabel('Frequency [GHz]'), ylabel('Power in dBm/MHz')
